@@ -21,9 +21,7 @@ bp = Blueprint("charts", __name__)
 @bp.route("/charts/cfgi/BTC/<frequency>", methods=["GET"])
 def cfgi_btc(frequency):
     response = requests.get(
-        url="{}charts/cfgi/BTC/{}".format(
-            current_app.config["SERVER_API_BASE_URL"], frequency
-        ),
+        url=f"{current_app.config['SERVER_API_BASE_URL']}charts/cfgi/BTC/{frequency}"
     )
     return response.json(), response.status_code
 
@@ -31,9 +29,7 @@ def cfgi_btc(frequency):
 @bp.route("/charts/<coin_or_token>/<frequency>", methods=["GET"])
 def coin_or_token_frequency(coin_or_token, frequency):
     response = requests.get(
-        url="{}charts/{}/{}".format(
-            current_app.config["SERVER_API_BASE_URL"], coin_or_token, frequency
-        ),
+        url=f"{current_app.config['SERVER_API_BASE_URL']}charts/{coin_or_token}/{frequency}"
     )
     return response.json(), response.status_code
 
@@ -41,9 +37,7 @@ def coin_or_token_frequency(coin_or_token, frequency):
 @bp.route("/charts/tether/<coin_or_token>/<frequency>", methods=["GET"])
 def tether(coin_or_token, frequency):
     response = requests.get(
-        url="{}charts/tether/{}/{}".format(
-            current_app.config["SERVER_API_BASE_URL"], coin_or_token, frequency
-        ),
+        url=f"{current_app.config['SERVER_API_BASE_URL']}charts/tether/{coin_or_token}/{frequency}"
     )
     return response.json(), response.status_code
 
@@ -51,8 +45,6 @@ def tether(coin_or_token, frequency):
 @bp.route("/charts/twitter/<project>/<frequency>", methods=["GET"])
 def twitter(project, frequency):
     response = requests.get(
-        url="{}charts/twitter/{}/{}".format(
-            current_app.config["SERVER_API_BASE_URL"], project, frequency
-        ),
+        url=f"{current_app.config['SERVER_API_BASE_URL']}charts/twitter/{project}/{frequency}"
     )
     return response.json(), response.status_code
