@@ -21,7 +21,7 @@ class Okcoin:
         url = self.base_url.format(*symbol)
         request = requests.get(url)
         if request.status_code != 200:
-            raise ValueError("Error connecting OkCoin on URL: {}".format(url))
+            raise ValueError(f"Error connecting OkCoin on URL: {url}")
         item = request.json()
         item.update(symbol="".join(symbol), ticker=symbol[0])
         return item
