@@ -20,7 +20,7 @@ class Okex:
         url = self.base_url.format(_symbol)
         request = requests.get(url)
         if request.status_code != 200:
-            raise ValueError("Error connecting OKEx on URL: {}".format(url))
+            raise ValueError(f"Error connecting OKEx on URL: {url}")
         item = request.json()
         item.update(ticker=symbol[0])
         return item
